.. Covalent Python API documentation master file, created by
   sphinx-quickstart on Wed Apr 14 20:11:32 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Covalent Python API's documentation!
===============================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   source/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
